package javax.management.relation;

import java.security.AccessController;
import com.sun.jmx.mbeanserver.GetPropertyAction;
import java.io.ObjectOutputStream;
import java.io.IOException;
import java.io.InvalidObjectException;
import com.sun.jmx.mbeanserver.Util;
import java.io.ObjectInputStream;
import java.util.Iterator;
import java.util.HashSet;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import javax.management.ObjectName;
import java.io.ObjectStreamField;
import javax.management.Notification;

public class RelationNotification extends Notification
{
    private static final long oldSerialVersionUID = -2126464566505527147L;
    private static final long newSerialVersionUID = -6871117877523310399L;
    private static final ObjectStreamField[] oldSerialPersistentFields;
    private static final ObjectStreamField[] newSerialPersistentFields;
    private static final long serialVersionUID;
    private static final ObjectStreamField[] serialPersistentFields;
    private static boolean compat;
    public static final String RELATION_BASIC_CREATION = "jmx.relation.creation.basic";
    public static final String RELATION_MBEAN_CREATION = "jmx.relation.creation.mbean";
    public static final String RELATION_BASIC_UPDATE = "jmx.relation.update.basic";
    public static final String RELATION_MBEAN_UPDATE = "jmx.relation.update.mbean";
    public static final String RELATION_BASIC_REMOVAL = "jmx.relation.removal.basic";
    public static final String RELATION_MBEAN_REMOVAL = "jmx.relation.removal.mbean";
    private String relationId;
    private String relationTypeName;
    private ObjectName relationObjName;
    private List<ObjectName> unregisterMBeanList;
    private String roleName;
    private List<ObjectName> oldRoleValue;
    private List<ObjectName> newRoleValue;
    
    public RelationNotification(String type, Object source, long sequenceNumber, long timeStamp, String message, String relationId, String relationTypeName, ObjectName objectName, List<ObjectName> list) throws IllegalArgumentException {
        super(type, source, sequenceNumber, timeStamp, message);
        this.relationId = null;
        this.relationTypeName = null;
        this.relationObjName = null;
        this.unregisterMBeanList = null;
        this.roleName = null;
        this.oldRoleValue = null;
        this.newRoleValue = null;
        if (!this.isValidBasicStrict(type, source, relationId, relationTypeName) || !this.isValidCreate(type)) {
            throw new IllegalArgumentException("Invalid parameter.");
        }
        this.relationId = relationId;
        this.relationTypeName = relationTypeName;
        this.relationObjName = this.safeGetObjectName(objectName);
        this.unregisterMBeanList = this.safeGetObjectNameList(list);
        return;
    }
    
    public RelationNotification(String type, Object source, long sequenceNumber, long timeStamp, String message, String relationId, String relationTypeName, ObjectName objectName, String roleName, List<ObjectName> list, List<ObjectName> list2) throws IllegalArgumentException {
        super(type, source, sequenceNumber, timeStamp, message);
        this.relationId = null;
        this.relationTypeName = null;
        this.relationObjName = null;
        this.unregisterMBeanList = null;
        this.roleName = null;
        this.oldRoleValue = null;
        this.newRoleValue = null;
        if (!this.isValidBasicStrict(type, source, relationId, relationTypeName) || !this.isValidUpdate(type, roleName, list, list2)) {
            throw new IllegalArgumentException("Invalid parameter.");
        }
        this.relationId = relationId;
        this.relationTypeName = relationTypeName;
        this.relationObjName = this.safeGetObjectName(objectName);
        this.roleName = roleName;
        this.oldRoleValue = this.safeGetObjectNameList(list2);
        this.newRoleValue = this.safeGetObjectNameList(list);
        return;
    }
    
    public String getRelationId() {
        return this.relationId;
    }
    
    public String getRelationTypeName() {
        return this.relationTypeName;
    }
    
    public ObjectName getObjectName() {
        return this.relationObjName;
    }
    
    public List<ObjectName> getMBeansToUnregister() {
        if (this.unregisterMBeanList != null) {
            return new ArrayList(this.unregisterMBeanList);
        }
        return Collections.emptyList();
    }
    
    public String getRoleName() {
        String roleName = null;
        if (this.roleName != null) {
            roleName = this.roleName;
            return roleName;
        }
        return roleName;
    }
    
    public List<ObjectName> getOldRoleValue() {
        if (this.oldRoleValue != null) {
            return new ArrayList(this.oldRoleValue);
        }
        return Collections.emptyList();
    }
    
    public List<ObjectName> getNewRoleValue() {
        if (this.newRoleValue != null) {
            return new ArrayList(this.newRoleValue);
        }
        return Collections.emptyList();
    }
    
    private boolean isValidBasicStrict(String s, Object o, String s2, String s3) {
        return o != null && this.isValidBasic(s, o, s2, s3);
    }
    
    private boolean isValidBasic(String s, Object o, String s2, String s3) {
        return s != null && s2 != null && s3 != null && (o == null || o instanceof RelationService || o instanceof ObjectName);
    }
    
    private boolean isValidCreate(String s) {
        return new HashSet(Arrays.asList(new String[] { "jmx.relation.creation.basic", "jmx.relation.creation.mbean", "jmx.relation.removal.basic", "jmx.relation.removal.mbean" })).contains(s);
    }
    
    private boolean isValidUpdate(String s, String s2, List<ObjectName> list, List<ObjectName> list2) {
        return (s.equals("jmx.relation.update.basic") || s.equals("jmx.relation.update.mbean")) && s2 != null && list2 != null && list != null;
    }
    
    private ArrayList<ObjectName> safeGetObjectNameList(List<ObjectName> list) {
        ArrayList<ObjectName> list2 = null;
        if (list != null) {
            list2 = new ArrayList();
            Iterator<Object> iterator = list.iterator();
            while (iterator.hasNext()) {
                list2.add(ObjectName.getInstance((ObjectName)iterator.next()));
            }
            return list2;
        }
        return list2;
    }
    
    private ObjectName safeGetObjectName(ObjectName name) {
        ObjectName instance = null;
        if (name != null) {
            instance = ObjectName.getInstance(name);
            return instance;
        }
        return instance;
    }
    
    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        ObjectInputStream.GetField fields = objectInputStream.readFields();
        String relationId;
        String relationTypeName;
        String roleName;
        ObjectName objectName;
        List<ObjectName> list;
        List<ObjectName> list2;
        List<ObjectName> list3;
        if (RelationNotification.compat) {
            relationId = (String)fields.get("myRelId", null);
            relationTypeName = (String)fields.get("myRelTypeName", null);
            roleName = (String)fields.get("myRoleName", null);
            objectName = (ObjectName)fields.get("myRelObjName", null);
            list = (List)Util.cast(fields.get("myNewRoleValue", null));
            list2 = (List)Util.cast(fields.get("myOldRoleValue", null));
            list3 = (List)Util.cast(fields.get("myUnregMBeanList", null));
        }
        else {
            relationId = (String)fields.get("relationId", null);
            relationTypeName = (String)fields.get("relationTypeName", null);
            roleName = (String)fields.get("roleName", null);
            objectName = (ObjectName)fields.get("relationObjName", null);
            list = (List)Util.cast(fields.get("newRoleValue", null));
            list2 = (List)Util.cast(fields.get("oldRoleValue", null));
            list3 = (List)Util.cast(fields.get("unregisterMBeanList", null));
        }
        String type = super.getType();
        if (!this.isValidBasic(type, super.getSource(), relationId, relationTypeName) || (!this.isValidCreate(type) && !this.isValidUpdate(type, roleName, list, list2))) {
            super.setSource(null);
            throw new InvalidObjectException("Invalid object read");
        }
        this.relationObjName = this.safeGetObjectName(objectName);
        this.newRoleValue = this.safeGetObjectNameList(list);
        this.oldRoleValue = this.safeGetObjectNameList(list2);
        this.unregisterMBeanList = this.safeGetObjectNameList(list3);
        this.relationId = relationId;
        this.relationTypeName = relationTypeName;
        this.roleName = roleName;
        return;
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        if (RelationNotification.compat) {
            ObjectOutputStream.PutField putFields = objectOutputStream.putFields();
            putFields.put("myNewRoleValue", this.newRoleValue);
            putFields.put("myOldRoleValue", this.oldRoleValue);
            putFields.put("myRelId", this.relationId);
            putFields.put("myRelObjName", this.relationObjName);
            putFields.put("myRelTypeName", this.relationTypeName);
            putFields.put("myRoleName", this.roleName);
            putFields.put("myUnregMBeanList", this.unregisterMBeanList);
            objectOutputStream.writeFields();
        }
        else {
            objectOutputStream.defaultWriteObject();
        }
    }
    
    static {
        oldSerialPersistentFields = new ObjectStreamField[] { new ObjectStreamField("myNewRoleValue", ArrayList.class), new ObjectStreamField("myOldRoleValue", ArrayList.class), new ObjectStreamField("myRelId", String.class), new ObjectStreamField("myRelObjName", ObjectName.class), new ObjectStreamField("myRelTypeName", String.class), new ObjectStreamField("myRoleName", String.class), new ObjectStreamField("myUnregMBeanList", ArrayList.class) };
        newSerialPersistentFields = new ObjectStreamField[] { new ObjectStreamField("newRoleValue", List.class), new ObjectStreamField("oldRoleValue", List.class), new ObjectStreamField("relationId", String.class), new ObjectStreamField("relationObjName", ObjectName.class), new ObjectStreamField("relationTypeName", String.class), new ObjectStreamField("roleName", String.class), new ObjectStreamField("unregisterMBeanList", List.class) };
        RelationNotification.compat = false;
        try {
            String s = (String)AccessController.doPrivileged(new GetPropertyAction("jmx.serial.form"));
            RelationNotification.compat = (s != null && s.equals("1.0"));
        }
        catch (Exception ex) {}
        if (RelationNotification.compat) {
            serialPersistentFields = RelationNotification.oldSerialPersistentFields;
            serialVersionUID = -2126464566505527147L;
        }
        else {
            serialPersistentFields = RelationNotification.newSerialPersistentFields;
            serialVersionUID = -6871117877523310399L;
        }
    }
}
